@@ -8,7 +8,6 @@
 # Description : ToolBox for the configuration of Sensirion sensors
 # ######################################################################################################################
 
-import time
 import os
 import logging
 
@@ -128,8 +127,9 @@ def scan_uart(port: str, measurement_obj=None):
                 _logger.debug("No update on a measurement object.")
             return uart_sensor(port)
         else:
-            _logger.debug(f"No known device @{port}")
+            _logger.debug(f"No known {uart_sensor} @ {port}")
 
+    _logger.info(f"No known device @ {port}")
     return None
 
 
