@@ -225,15 +225,15 @@ class SCD30(I2CSensor):
                 crc_init=self._crc_check_init,
             )[0]
         cmd = self.__cmd_cont_meas + [p_msb, p_lsb, p_crc]
-        self._logger.warning(f"init cmd not send (legacy) {cmd}")
-        # self.txrx(cmd)
+        # self._logger.warning(f"init cmd not send (legacy) {cmd}")
+        self.txrx(cmd)
         time.sleep(self.measurement_intervall + 1)
 
     def get_data_rdy(self):
         data = self.txrx(self.__cmd_get_data_rdy, readlen=3)
         if data is not None and data[1] == 0x01:
             return True
-        self._logger.info("Data is not ready.")
+        self._logger.debug("Data is not ready.")
         return False
 
     def get_data(self):
