@@ -120,7 +120,7 @@ class SHT85(I2CSensor):
             attempts += 1
             data = self.txrx([], readlen=6)
 
-        if data is not None:
+        if data is not None and len(data) == 6:
             check0 = Error.checksum([data[0], data[1]], data[2])
             check1 = Error.checksum([data[3], data[4]], data[5])
             if check0[1] and check1[1]:
