@@ -6,10 +6,10 @@
 Example script for running a measurement using i2c senors only.
 """
 
-from pySerialMeasurement.devices.FTDI import init_all
-from pySerialMeasurement.tools.bulk import setup, ThreadWithReturnValue
-from pySerialMeasurement.core.i2controller import MmsI2cController
-from pySerialMeasurement.core.i2controller import MmsSpiController
+from pyserialsensors.devices.FTDI import init_all
+from pyserialsensors.tools.bulk import setup, ThreadWithReturnValue
+from pyserialsensors.core.i2controller import MmsI2cController
+from pyserialsensors.core.i2controller import MmsSpiController
 
 import logging
 
@@ -48,10 +48,10 @@ def runMeasurement(setup):
                                 s["obj"].disconnected_ftdi = False
                             val = sensor["obj"].get_data()
                             out = f"{val['sensor_type']: >10}"
-                            if val["serialno"] is None:
+                            if val["SENSORserial"] is None:
                                 out += f"{'': >20}"
                             else:
-                                out += f"{val['serialno']: >20}"
+                                out += f"{val['SENSORserial']: >20}"
                             if "values" in val:
                                 for value in val["values"]:
                                     v = val["values"][value]["value"]
@@ -68,10 +68,10 @@ def runMeasurement(setup):
                     val = sensor["obj"].get_data()
                     out = f"{val['sensor_type']: >10}"
 
-                    if val["serialno"] is None:
+                    if val["SENSORserial"] is None:
                         out += f"{'': >20}"
                     else:
-                        out += f"{val['serialno']: >20}"
+                        out += f"{val['SENSORserial']: >20}"
                     if "values" in val:
                         for qty in val["values"]:
                             if val["values"][qty]["value"] is not None:
